# Generated by roxygen2: do not edit by hand

export(aggr_es)
export(ggcoefplot)
export(ggiplot)
export(iplot_data)
import(fixest)
import(ggplot2)
importFrom(fixest,coefplot)
importFrom(fixest,iplot)
importFrom(marginaleffects,hypotheses)
